#ifndef STRINGLISTEDIT_H
#define STRINGLISTEDIT_H

#include <qdialog.h>

class QListBox;
class QPushButton;
class QStringList;

class StringListEdit : public QDialog
{
    Q_OBJECT

public:
    StringListEdit(const QStringList &list = QStringList(),
                   QWidget *parent = 0);

    void setTexts(const QString &addCaption, const QString &addLabel,
                  const QString &editCaption, const QString &editLabel = "");
    bool askBeforeRemoving() const { return ask; }
    void setAskBeforeRemoving(bool a) { ask = a; }
    bool allowDuplicates() const { return duplicatesOk; }
    void setAllowDuplicates(bool allow) { duplicatesOk = allow; }
    QStringList list() const;
    void setList(const QStringList &list);

protected slots:
    virtual void addString();
    virtual void editString();
    virtual void removeString();
    void updateButtons();

private slots:
    void moveUp();
    void moveDown();

protected:
    QString addCaption;
    QString addLabel;
    QString editCaption;
    QString editLabel;
    bool ask;
    bool duplicatesOk;
    QListBox *listBox;

private:
    QPushButton *editButton;
    QPushButton *removeButton;
    QPushButton *upButton;
    QPushButton *downButton;
};

class FileListEdit : public StringListEdit
{
    Q_OBJECT

public:
    FileListEdit(const QStringList &list=QStringList(), QWidget *parent = 0)
        : StringListEdit(list, parent),
          filter(tr("Any (*;*.*)")), path(".")
        {}

    QString fileFilter() const { return filter; }
    void setFileFilter(const QString &filter) { this->filter = filter; }

private slots:
    void addString();
    void editString();

private:
    QString filter;
    QString path;
};

#endif
